/***************************************************************************************************
 * Copyright (c) 2003, 2020 IBM Corporation and others. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/

 * 
 * Contributors: IBM Corporation - initial API and implementation
 **************************************************************************************************/
package org.eclipse.wst.common.internal.emf.utilities;

public class InvalidPasswordEncodingException extends PasswordException {

	/**
	 * 
	 */
	private static final long serialVersionUID = -1320759752706898095L;
}

